@@ -1,15 +1,15 @@
 context("test purge_dimensions_constellation")
 
 test_that("purge_dimensions_constellation works", {
-  st1 <- ct_mrs_test$star$mrs_age %>%
+  st1 <- ct_mrs_test$star$mrs_age |>
     filter_fact_rows(name = "where", city == "Bridgepor")
 
-  st2 <- ct_mrs_test$star$mrs_cause %>%
+  st2 <- ct_mrs_test$star$mrs_cause |>
     filter_fact_rows(name = "where", city == "Bridgepor")
 
-  ct <- ct_mrs_test %>%
-    incremental_refresh_constellation(st1, existing = "delete") %>%
-    incremental_refresh_constellation(st2, existing = "delete") %>%
+  ct <- ct_mrs_test |>
+    incremental_refresh_constellation(st1, existing = "delete") |>
+    incremental_refresh_constellation(st2, existing = "delete") |>
     purge_dimensions_constellation()
 
   expect_equal(
@@ -23,8 +23,8 @@ test_that("purge_dimensions_constellation works", {
         city = c("Bridgeport", "Tacoma")
       ),
       row.names = 1:2,
-      class = c("tbl_df",
-                "tbl", "data.frame", "dimension_table"),
+      class = c("dimension_table", "tbl_df",
+                "tbl", "data.frame"),
       name = "where",
       type = "conformed"
     )
