@@ -1,15 +1,13 @@
 context("test update_record")
 
 test_that("update_record works", {
-  library(tidyr)
-
-  where <- st_mrs_age_test %>%
+  where <- st_mrs_age_test |>
     get_dimension("where")
 
-  updates <- record_update_set() %>%
+  updates <- record_update_set() |>
     update_record(dimension = where,
                   old = 1,
-                  values = c("1", "CT", "Bridgeport")) %>%
+                  values = c("1", "CT", "Bridgeport")) |>
     update_record(dimension = where,
                   old = 1,
                   values = c("1", "CT", "Bridgeport"))
